<?php
/**
 * @file
 * Lingotek Translation Sync Process.
 */


/**
 * Upload Batch Worker Function: Upload Node for Translation
 */
function lingotek_mt_sync_upload_node( $nid, &$context ) {

  watchdog( 'ltk_upload_node', 'node: @node_id', array( '@node_id' => $nid ), WATCHDOG_DEBUG );

  $api = LingotekApi::instance();
  $node = node_load( $nid );

  // Push this node for translation.
  if ($existing_document = lingotek_lingonode($node->nid, 'document_id')) {
    // Update an existing Lingotek Document.
    $api->updateContentDocument($node);
  }
  else {
    // Create a new Lingotek Document.
    $api->addContentDocument($node, TRUE);
  }

  // Set this Node and its targets to PENDING status. (meaning the content has been uploaded, but not downloaded)
  lingotek_set_node_and_targets_sync_status( $nid, LINGOTEK_NODE_SYNC_STATUS_PENDING, LINGOTEK_TARGET_SYNC_STATUS_PENDING );
  $context['results'][] = 'Upload Node: ' . $nid;

} // END:  lingotek_machine_translate_node();


/**
 * Download Batch Worker Function: Download Translated Node Content
 *
 * CRITICAL:
 *   Updating the node w/ the new language translation will cause the document to be flagged edited.
 *   So before that, the current node and target states have to be grabed and saved so they can be restored after the update.
 */
function lingotek_mt_sync_download_node_target( $nid, $drupal_language_code, &$context ) {

  watchdog( 'ltk_download_target', 'node: @node_id (@language)', array( '@node_id' => $nid, '@language' => $drupal_language_code ), WATCHDOG_DEBUG );

  $node = node_load($nid);

  // CRITICAL:  lingotek_download_document() WILL EDIT THE DOCUMENT.
  // So first, Get the CURRENT Document and Target Sync Statuses, so we can restore those again after downloading the document.
  $node_status_array = lingotek_get_node_and_target_sync_status( $nid );

  $node->lingotek_upload_override = 0;
  lingotek_download_document($node, $drupal_language_code);
  $context['results'][] = t('Download Target Translation: Node #@nid (@langcode)', array('@nid'=>$nid,'@langcode'=>$drupal_language_code));

  // TEMP CHECK
  /*$node_status_array1 = lingotek_get_node_and_target_sync_status( $nid );
  watch_dog('ltk_download','compare: <h2>before</h2> @s1 <h2>after</h2> @s2',array(
    '@s1' => watchdog_format_object($node_status_array),
    '@s2' => watchdog_format_object($node_status_array1)
  ));*/
  
  // Set this Target status to CURRENT.
  $node_status_array[ 'targets' ][ $drupal_language_code ] = LINGOTEK_TARGET_SYNC_STATUS_CURRENT;

  // Check:  Are all targets CURRENT?  If so, mark the Node CURRENT.
  $all_targets_current = TRUE;
  foreach ( $node_status_array[ 'targets' ] AS $language => $status ) {
    if ( $status != LINGOTEK_TARGET_SYNC_STATUS_CURRENT ) {
      $all_targets_current = FALSE;
      break;
    }
  }
  // If, after the check, $all_targets_current is still TRUE, mark the Node status CURRENT.
  if ( $all_targets_current === TRUE ) {
    $node_status_array[ 'node_sync_status' ] = LINGOTEK_NODE_SYNC_STATUS_CURRENT;
  }

  // Save the $node_status_array
  lingotek_set_node_and_targets_sync_status_by_array( $nid, $node_status_array ); 

}


/**
 * Sets and clears session sync flags.
 */
function lingotek_mt_sync_set_status( $status, &$context ) {

  switch ($status) {
    case 'set':
      $_SESSION['lingotek_sync_in_progress'] = 'syncing';
      break;
    case 'clear':
      if ( isset( $_SESSION['lingotek_sync_in_progress'] ) ) {
        unset($_SESSION['lingotek_sync_in_progress']);
      }
      break;
  }

}
